@@ -13,14 +13,15 @@ rec_base <- recipe(~ ., data = test_data)
 # Create some manual data for expected results.
 tokens <- rec_base %>% 
   step_tokenize(text) %>%
-  recipes::prep(training = test_data) %>%
+  recipes::prep() %>%
   recipes::juice() %>% 
-  dplyr::bind_cols(test_data) %>% 
+  vctrs::vec_cbind(rename(test_data, text1 = text)) %>% 
   dplyr::select(text = text1, tokens = text)
 
 # Give each token an arbitrary value for comparison. Real embeddings will be
 # doubles, so make these double.
 embeddings <- tokens %>% 
+  dplyr::mutate(tokens = vctrs::field(tokens, "tokens")) %>%
   tidyr::unnest(tokens) %>% 
   dplyr::distinct(tokens) %>%
   dplyr::arrange(tokens) %>% 
@@ -44,6 +45,7 @@ embeddings <- tokens %>%
   )
 
 sentence_embeddings_long <- tokens %>% 
+  dplyr::mutate(tokens = vctrs::field(tokens, "tokens")) %>%
   tidyr::unnest(tokens) %>% 
   dplyr::left_join(embeddings, by = "tokens")
 
@@ -97,7 +99,7 @@ rec <- rec_base %>%
   step_word_embeddings(text, embeddings = embeddings)
 
 obj <- rec %>%
-  prep(training = test_data, retain = TRUE)
+  prep()
 
 juiced <- juice(obj)
 
@@ -147,7 +149,7 @@ test_that("step_word_embeddings aggregates vectors as expected.", {
     step_word_embeddings(
       text, embeddings = embeddings, aggregation = "max"
     ) %>% 
-    prep(training = test_data, retain = TRUE) %>% 
+    prep() %>% 
     juice()
   expect_identical(juiced_max, select(sentence_embeddings_max, -text))
   juiced_min <- rec_base %>% 
@@ -155,7 +157,7 @@ test_that("step_word_embeddings aggregates vectors as expected.", {
     step_word_embeddings(
       text, embeddings = embeddings, aggregation = "min"
     ) %>% 
-    prep(training = test_data, retain = TRUE) %>% 
+    prep() %>% 
     juice()
   expect_identical(juiced_min, select(sentence_embeddings_min, -text))
   juiced_mean <- rec_base %>% 
@@ -163,7 +165,7 @@ test_that("step_word_embeddings aggregates vectors as expected.", {
     step_word_embeddings(
       text, embeddings = embeddings, aggregation = "mean"
     ) %>% 
-    prep(training = test_data, retain = TRUE) %>% 
+    prep() %>% 
     juice()
   expect_identical(juiced_mean, select(sentence_embeddings_mean, -text))
 })
@@ -207,7 +209,7 @@ test_that("printing", {
     "Word embeddings aggregated from text"
   )
   expect_output(
-    prep(rec, training = test_data, verbose = TRUE)
+    prep(rec, verbose = TRUE)
   )
 })
 
@@ -222,3 +224,4 @@ test_that("NA tokens work.", {
   )
   expect_identical(test_result, expected_result)
 })
+
