@@ -16,7 +16,7 @@ test_that("output is list when length is 1 or 0", {
   
   data_rec <- recipe(~ ., data = data) %>%
     step_tokenize(a) %>%
-    prep(training = data, retain = TRUE)
+    prep()
   
   expect_true(is.list(juice(data_rec, a)[, 1, drop = TRUE]))
 })
@@ -26,14 +26,14 @@ test_that("tokenization is done correctly", {
     step_tokenize(text) 
   
   obj <- rec %>%
-    prep(training = test_data, retain = TRUE)
+    prep()
   
   expect_equal(
     list(c("i", "would", "not", "eat", "them", "here", "or", "there"),
          c("i", "would", "not", "eat", "them", "anywhere"),
          c("i", "would", "not", "eat", "green", "eggs", "and", "ham"),
          c("i", "do", "not", "like", "them", "sam", "i", "am")),
-    juice(obj) %>% pull(text)
+    juice(obj) %>% pull(text) %>% vctrs::field("tokens")
   )
   
   expect_equal(dim(recipes:::tidy.recipe(rec, 1)), c(1, 3))
@@ -44,45 +44,79 @@ test_that("step throws an error if unavaliable tokenizer is picked", {
   expect_error(
     rec %>%
       step_tokenize(text, token = "wrong") %>%
-      prep(training = test_data, retain = TRUE)
+      prep()
   )
 })
 
 test_that("tokenization works with other built-in tokenizers", {
   rec <- rec %>%
     step_tokenize(text, token = "characters") %>%
-    prep(training = test_data, retain = TRUE)
+    prep()
   
   expect_equal(
     tokenizers::tokenize_characters(test_data$text[1]),
-    juice(rec) %>% slice(1) %>% pull(text)
+    juice(rec) %>% slice(1) %>% pull(text) %>% vctrs::field("tokens")
   )
 })
 
 test_that("tokenization works with custom tokenizer", {
   rec <- rec %>%
     step_tokenize(text, custom_token = tokenizers::tokenize_characters) %>%
-    prep(training = test_data, retain = TRUE)
+    prep()
   
   expect_equal(
     tokenizers::tokenize_characters(test_data$text[1]),
     juice(rec) %>% 
       slice(1) %>% 
-      pull(text)
+      pull(text) %>% 
+      vctrs::field("tokens")
   )
 })
 
 test_that("arguments are passed using options argument", {
   rec <- rec %>%
     step_tokenize(text, options = list(lowercase = FALSE)) %>%
-    prep(training = test_data, retain = TRUE)
+    prep()
   
   expect_equal(
     list(c("I", "would", "not", "eat", "them", "here", "or", "there"),
          c("I", "would", "not", "eat", "them", "anywhere"),
          c("I", "would", "not", "eat", "green", "eggs", "and", "ham"),
          c("I", "do", "not", "like", "them", "Sam", "I", "am")),
-    juice(rec) %>% pull(text)
+    juice(rec) %>% pull(text) %>% vctrs::field("tokens")
+  )
+})
+
+test_that("tokenization errors with wrong engines", {
+  expect_error(
+    rec %>%
+      step_tokenize(text, engine = "fake") %>%
+      prep()
+  )
+})
+
+test_that("tokenization includes lemma attribute when avaliable", {
+  skip_if_no_python_or_no_spacy()
+  
+  expect_type(
+    rec %>%
+      step_tokenize(text, engine = "spacyr") %>%
+      prep() %>%
+      juice() %>%
+      .$text %>%
+      vctrs::field("lemma"), 
+    "list"
+    )
+})
+  
+test_that("tokenization doesn't includes lemma attribute when unavaliable", {
+  expect_null(
+    rec %>%
+      step_tokenize(text) %>%
+      prep() %>%
+      juice() %>%
+      .$text %>%
+      attr("lemma")
   )
 })
 
@@ -90,5 +124,6 @@ test_that("printing", {
   rec <- rec %>%
     step_tokenize(text)
   expect_output(print(rec))
-  expect_output(prep(rec, training = test_data, verbose = TRUE))
+  expect_output(prep(rec, verbose = TRUE))
 })
+
